@@ -25,19 +25,22 @@
 #include <QDBusContext>
 
 #include "access.h"
+#include "account.h"
 #include "appchooser.h"
+#include "background.h"
 #include "email.h"
 #include "filechooser.h"
 #include "inhibit.h"
 #include "notification.h"
 #include "print.h"
-#if SCREENCAST_ENABLED
-#include "screencast.h"
-#include "remotedesktop.h"
-#include "waylandintegration.h"
-#endif
 #include "screenshot.h"
 #include "settings.h"
+#include "waylandintegration.h"
+
+#if HAVE_PIPEWIRE_SUPPORT
+#include "screencast.h"
+#include "remotedesktop.h"
+#endif
 
 class DesktopPortal : public QObject, public QDBusContext
 {
@@ -48,18 +51,20 @@ public:
 
 private:
     AccessPortal *m_access;
+    AccountPortal *m_account;
     AppChooserPortal *m_appChooser;
+    BackgroundPortal *m_background;
     EmailPortal *m_email;
     FileChooserPortal *m_fileChooser;
     InhibitPortal *m_inhibit;
     NotificationPortal *m_notification;
     PrintPortal *m_print;
-#if SCREENCAST_ENABLED
+    ScreenshotPortal *m_screenshot;
+    SettingsPortal *m_settings;
+#if HAVE_PIPEWIRE_SUPPORT
     ScreenCastPortal *m_screenCast;
     RemoteDesktopPortal *m_remoteDesktop;
 #endif
-    ScreenshotPortal *m_screenshot;
-    SettingsPortal *m_settings;
 };
 
 #endif // XDG_DESKTOP_PORTAL_KDE_DESKTOP_PORTAL_H
